# -*- coding: utf-8 -*-
from django.conf.urls import *
from yamoney.views import NotificationView

urlpatterns = patterns(
    '',
    url(r'^notification/$', NotificationView.as_view(), name='yamoney_notification')
)


# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):

        # Changing field 'Transaction.withdraw_amount'
        db.alter_column(u'yamoney_transaction', 'withdraw_amount', self.gf('django.db.models.fields.FloatField')(null=True))

    def backwards(self, orm):

        # Changing field 'Transaction.withdraw_amount'
        db.alter_column(u'yamoney_transaction', 'withdraw_amount', self.gf('django.db.models.fields.FloatField')(default=None))

    models = {
        u'yamoney.transaction': {
            'Meta': {'object_name': 'Transaction'},
            'amount': ('django.db.models.fields.FloatField', [], {}),
            'codepro': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'currency': ('django.db.models.fields.CharField', [], {'default': "'643'", 'max_length': '100'}),
            'datetime': ('django.db.models.fields.DateTimeField', [], {}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'label': ('django.db.models.fields.CharField', [], {'max_length': '255', 'blank': 'True'}),
            'notification_type': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'operation_id': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'sender': ('django.db.models.fields.CharField', [], {'max_length': '255', 'blank': 'True'}),
            'withdraw_amount': ('django.db.models.fields.FloatField', [], {'null': 'True', 'blank': 'True'})
        }
    }

    complete_apps = ['yamoney']


# -*- coding: utf-8 -*-
from django.views.generic.edit import CreateView
from django.views.decorators.csrf import csrf_exempt
from django.utils.decorators import method_decorator
from django.http import HttpResponse, HttpResponseBadRequest
from yamoney.forms import YandexNotificationForm


class NotificationView(CreateView):
    form_class = YandexNotificationForm
    http_method_names = ('post',)

    @method_decorator(csrf_exempt)
    def dispatch(self, request, *args, **kwargs):
        return super(NotificationView, self).dispatch(request, *args, **kwargs)

    def form_invalid(self, form):
        return HttpResponseBadRequest()

    def form_valid(self, form):
        self.object = form.save()
        return HttpResponse()


# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Transaction'
        db.create_table(u'yamoney_transaction', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('notification_type', self.gf('django.db.models.fields.CharField')(max_length=100)),
            ('operation_id', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('amount', self.gf('django.db.models.fields.FloatField')()),
            ('withdraw_amount', self.gf('django.db.models.fields.FloatField')()),
            ('currency', self.gf('django.db.models.fields.CharField')(default='643', max_length=100)),
            ('datetime', self.gf('django.db.models.fields.DateTimeField')()),
            ('sender', self.gf('django.db.models.fields.CharField')(max_length=255, blank=True)),
            ('codepro', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('label', self.gf('django.db.models.fields.CharField')(max_length=255, blank=True)),
        ))
        db.send_create_signal(u'yamoney', ['Transaction'])


    def backwards(self, orm):
        # Deleting model 'Transaction'
        db.delete_table(u'yamoney_transaction')


    models = {
        u'yamoney.transaction': {
            'Meta': {'object_name': 'Transaction'},
            'amount': ('django.db.models.fields.FloatField', [], {}),
            'codepro': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'currency': ('django.db.models.fields.CharField', [], {'default': "'643'", 'max_length': '100'}),
            'datetime': ('django.db.models.fields.DateTimeField', [], {}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'label': ('django.db.models.fields.CharField', [], {'max_length': '255', 'blank': 'True'}),
            'notification_type': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'operation_id': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'sender': ('django.db.models.fields.CharField', [], {'max_length': '255', 'blank': 'True'}),
            'withdraw_amount': ('django.db.models.fields.FloatField', [], {})
        }
    }

    complete_apps = ['yamoney']


# -*- coding: utf-8 -*-
from django.db import models
from django.utils import timezone
from django.utils import formats


class Transaction(models.Model):
    NOTIFICATION_TYPE_CHOICES = (
        ('p2p-incoming', u'Перевод из кошелька'),
        ('card-incoming', u'Перевод с карты'),
    )
    CURRENCY_CHOICES = (
        ('643', u'руб.'),
    )

    notification_type = models.CharField(u'Тип операции', max_length=100, choices=NOTIFICATION_TYPE_CHOICES)
    operation_id = models.CharField(u'Идентификатор операции', max_length=255)
    amount = models.FloatField(u'Сумма, которая зачислена на счет получателя')
    withdraw_amount = models.FloatField(u'Сумма, которая списана со счета отправителя', blank=True, null=True)
    currency = models.CharField(u'Валюта', max_length=100, choices=CURRENCY_CHOICES, default=CURRENCY_CHOICES[0][0])
    datetime = models.DateTimeField(u'Дата и время совершения перевода')
    sender = models.CharField(u'Номер счета отправителя', max_length=255, blank=True,
                              help_text=u'Только для переводов из кошелька')
    codepro = models.BooleanField(u'Служебное')
    label = models.CharField(u'Метка платежа', max_length=255, blank=True)

    class Meta:
        verbose_name = u'Перевод'
        verbose_name_plural = u'Переводы'

    def __unicode__(self):
        return u'%s на сумму %.2f %s от %s' % (
            self.get_notification_type_display(),
            self.withdraw_amount or 0,
            self.get_currency_display(),
            formats.date_format(timezone.localtime(self.datetime), 'DATETIME_FORMAT')
        )